# Error Handling

## Exception Matchers

::: geneva.debug.error_store.Retry

::: geneva.debug.error_store.Skip

::: geneva.debug.error_store.Fail

## Helper Functions

::: geneva.debug.error_store.retry_transient

::: geneva.debug.error_store.retry_all

::: geneva.debug.error_store.skip_on_error

::: geneva.debug.error_store.fail_fast

## Configuration

::: geneva.debug.error_store.ErrorHandlingConfig

::: geneva.debug.error_store.UDFRetryConfig

::: geneva.debug.error_store.ErrorRecord
